

# MSI

Un package Python pour les calculs mathématiques courants



## Documentation

Pour accéder à la documentation de `MSI`, cliquez sur le lien suivant :

[Documentation MSI](https://stagee.readthedocs.io/en/latest/)

Merci d'avoir utilisé MSI ! Nous espérons qu’il vous
